Crate dirk_macros

Crate dirk_macros 

Macros for compile-time dependency injection

Attribute Macros

component
Declares a component that may be used to instantiate types.
provides
Annotates an impl block containing a function that provides an instance of a certain type
use_component
May be used to facilitate using components defined in a different module
use_provides
May be used to facilitate injecting or querying types provided in a different module