Macros for compile-time dependency injection
Attribute Macros
- component
- Declares a component that may be used to instantiate types.
- provides
- Annotates an
implblock containing a function that provides an instance of a certain type - use_
component - May be used to facilitate using components defined in a different module
- use_
provides - May be used to facilitate injecting or querying types provided in a different module